# TimedAudioPlayer
An audio player that will play audio files in a directory for a specified amount of time.

## Dependencies
Python 3.9+

## Installation

```shell
pip install timed-audio-player
```

## Usage

```shell
timed-audio-player "/home/ambauma/Music/Audiobooks/AudiobookSeries" 60000
```